"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var _1 = require(".");
describe('patternMatch', function () {
    describe('pattern matching on primatives', function () {
        var matchStringToNumber = function (val) {
            return _1.patternMatch(val, [
                {
                    case: 'one',
                    do: function () { return 1; },
                },
                {
                    case: 'two',
                    do: function () { return 2; },
                },
            ], function () {
                return 712;
            });
        };
        it('matches provided cases', function () {
            expect(matchStringToNumber('one')).toBe(1);
            expect(matchStringToNumber('two')).toBe(2);
        });
        it('returns a default if no case matches', function () {
            expect(matchStringToNumber('some not found')).toBe(712);
        });
    });
    describe('pattern matching on tuples', function () {
        var matchTupleToNumber = function (tuple) {
            return _1.patternMatch(tuple, [
                {
                    case: [true, 7, 'ooooh weee!', { name: 'MPB' }],
                    do: function () { return 'good friend'; },
                },
                {
                    case: [false, 4, 'wubalubadubdub', { name: 'Rick' }],
                    do: function () { return 'sanchez'; },
                },
            ], function () {
                return 'the default';
            });
        };
        it('matches provided cases', function () {
            expect(matchTupleToNumber([true, 7, 'ooooh weee!', { name: 'MPB' }])).toBe('good friend');
            expect(matchTupleToNumber([false, 4, 'wubalubadubdub', { name: 'Rick' }])).toBe('sanchez');
        });
        it('returns a default if no case matches', function () {
            expect(matchTupleToNumber([true, 9, 'nope', { name: 'pencilvester' }])).toBe('the default');
        });
    });
});
//# sourceMappingURL=index.test.js.map